@@ -88,4 +88,9 @@ void Source::switchStreams()
     });
 }
 
+quint32 Source::sourceIndex() const
+{
+    return index();
+}
+
 } // QPulseAudio
